import value from "./async";

it("should have the correct values", function() {
	expect(value).toBe("default");
});
